@@ -25,6 +25,7 @@ _N_SAMPLE_POLYGON_INTERSECT = 100
 _IS_CLOSE_RTOL = np.finfo(float).eps
 
 
+# pylint:disable=too-many-public-methods
 class Geometry(Tidy3dBaseModel, ABC):
     """Abstract base class, defines where something exists in space."""
 
@@ -557,6 +558,158 @@ class Geometry(Tidy3dBaseModel, ABC):
     def _surface_area(self, bounds: Bound) -> float:
         """Returns object's surface area given bounds."""
 
+    """ Field and coordinate transformations """
+
+    @staticmethod
+    def car_2_sph(x: float, y: float, z: float) -> Tuple[float, float, float]:
+        """Convert Cartesian to spherical coordinates.
+
+        Parameters
+        ----------
+        x : float
+            x coordinate relative to ``local_origin``.
+        y : float
+            y coordinate relative to ``local_origin``.
+        z : float
+            z coordinate relative to ``local_origin``.
+
+        Returns
+        -------
+        Tuple[float, float, float]
+            r, theta, and phi coordinates relative to ``local_origin``.
+        """
+        r = np.sqrt(x**2 + y**2 + z**2)
+        theta = np.arccos(z / r)
+        phi = np.arctan2(y, x)
+        return r, theta, phi
+
+    @staticmethod
+    def sph_2_car(r: float, theta: float, phi: float) -> Tuple[float, float, float]:
+        """Convert spherical to Cartesian coordinates.
+
+        Parameters
+        ----------
+        r : float
+            radius.
+        theta : float
+            polar angle (rad) downward from x=y=0 line.
+        phi : float
+            azimuthal (rad) angle from y=z=0 line.
+
+        Returns
+        -------
+        Tuple[float, float, float]
+            x, y, and z coordinates relative to ``local_origin``.
+        """
+        r_sin_theta = r * np.sin(theta)
+        x = r_sin_theta * np.cos(phi)
+        y = r_sin_theta * np.sin(phi)
+        z = r * np.cos(theta)
+        return x, y, z
+
+    @staticmethod
+    def sph_2_car_field(
+        f_r: float, f_theta: float, f_phi: float, theta: float, phi: float
+    ) -> Tuple[complex, complex, complex]:
+        """Convert vector field components in spherical coordinates to cartesian.
+
+        Parameters
+        ----------
+        f_r : float
+            radial component of the vector field.
+        f_theta : float
+            polar angle component of the vector fielf.
+        f_phi : float
+            azimuthal angle component of the vector field.
+        theta : float
+            polar angle (rad) of location of the vector field.
+        phi : float
+            azimuthal angle (rad) of location of the vector field.
+
+        Returns
+        -------
+        Tuple[float, float, float]
+            x, y, and z components of the vector field in cartesian coordinates.
+        """
+        sin_theta = np.sin(theta)
+        cos_theta = np.cos(theta)
+        sin_phi = np.sin(phi)
+        cos_phi = np.cos(phi)
+        f_x = f_r * sin_theta * cos_phi + f_theta * cos_theta * cos_phi - f_phi * sin_phi
+        f_y = f_r * sin_theta * sin_phi + f_theta * cos_theta * sin_phi + f_phi * cos_phi
+        f_z = f_r * cos_theta - f_theta * sin_theta
+        return f_x, f_y, f_z
+
+    @staticmethod
+    def car_2_sph_field(
+        f_x: float, f_y: float, f_z: float, theta: float, phi: float
+    ) -> Tuple[complex, complex, complex]:
+        """Convert vector field components in cartesian coordinates to spherical.
+
+        Parameters
+        ----------
+        f_x : float
+            x component of the vector field.
+        f_y : float
+            y component of the vector fielf.
+        f_z : float
+            z component of the vector field.
+        theta : float
+            polar angle (rad) of location of the vector field.
+        phi : float
+            azimuthal angle (rad) of location of the vector field.
+
+        Returns
+        -------
+        Tuple[float, float, float]
+            radial (s), elevation (theta), and azimuthal (phi) components
+            of the vector field in spherical coordinates.
+        """
+        sin_theta = np.sin(theta)
+        cos_theta = np.cos(theta)
+        sin_phi = np.sin(phi)
+        cos_phi = np.cos(phi)
+        f_r = f_x * sin_theta * cos_phi + f_y * sin_theta * sin_phi + f_z * cos_theta
+        f_theta = f_x * cos_theta * cos_phi + f_y * cos_theta * sin_phi - f_z * sin_theta
+        f_phi = -f_x * sin_phi + f_y * cos_phi
+        return f_r, f_theta, f_phi
+
+    @staticmethod
+    def kspace_2_sph(ux: float, uy: float, axis: Axis) -> Tuple[float, float]:
+        """Convert normalized k-space coordinates to angles.
+
+        Parameters
+        ----------
+        ux : float
+            normalized kx coordinate.
+        uy : float
+            normalized ky coordinate.
+        axis : int
+            axis along which the observation plane is oriented.
+
+        Returns
+        -------
+        Tuple[float, float]
+            theta and phi coordinates relative to ``local_origin``.
+        """
+        phi_local = np.arctan2(uy, ux)
+        theta_local = np.arcsin(np.sqrt(ux**2 + uy**2))
+        # Spherical coordinates rotation matrix reference:
+        # https://en.wikipedia.org/wiki/Rodrigues%27_rotation_formula#Matrix_notation
+        if axis == 2:
+            return theta_local, phi_local
+
+        x = np.cos(theta_local)
+        y = np.sin(theta_local) * np.sin(phi_local)
+        z = -np.sin(theta_local) * np.cos(phi_local)
+
+        if axis == 1:
+            x, y, z = -z, x, -y
+
+        theta = np.arccos(z)
+        phi = np.arctan2(y, x)
+        return theta, phi
+
 
 """ Abstract subclasses """
 
@@ -677,6 +830,23 @@ class Planar(Geometry, ABC):
         bounds_max = self.unpop_axis(z_max, (xmax, ymax), axis=self.axis)
         return bounds_min, bounds_max
 
+    def _order_axis(self, axis: int) -> int:
+        """Order the axis as if self.axis is along z-direction.
+
+        Parameters
+        ----------
+        axis : int
+            Integer index into the structure's planar axis.
+
+        Returns
+        -------
+        int
+            New index of axis.
+        """
+        axis_index = [0, 1]
+        axis_index.insert(self.axis, 2)
+        return axis_index[axis]
+
     def _order_by_axis(self, plane_val: Any, axis_val: Any, axis: int) -> Tuple[Any, Any]:
         """Orders a value in the plane and value along axis in correct (x,y) order for plotting.
            Note: sometimes if axis=1 and we compute cross section values orthogonal to axis,
@@ -1404,7 +1574,7 @@ class PolySlab(Planar):
         description="Angle of the sidewall. "
         "``sidewall_angle=0`` (default) specifies vertical wall, "
         "while ``0<sidewall_angle<np.pi/2`` for the base to be larger than the top, "
-        "and ``np.pi/2<sidewall_angle<0`` for base to be smaller than the top.",
+        "and ``-np.pi/2<sidewall_angle<0`` for base to be smaller than the top.",
         gt=-np.pi / 2,
         lt=np.pi / 2,
         units=RADIAN,
@@ -1414,20 +1584,12 @@ class PolySlab(Planar):
         ...,
         title="Vertices",
         description="List of (d1, d2) defining the 2 dimensional positions of the base polygon "
-        "face vertices along dimensions parallel to slab normal axis.",
+        "face vertices along dimensions parallel to slab normal axis. The index of dimension "
+        "should be in the ascending order: e.g. if the slab normal axis is `y`, the coordinate "
+        "of the vertices will be in (x, z)",
         units=MICROMETER,
     )
 
-    @pydantic.validator("axis", always=True)
-    def supports_z_axis_only(cls, val):
-        """PolySlab can only be oriented in z right now."""
-        if val != 2:
-            raise ValidationError(
-                "PolySlab can only support axis=2 in this version of Tidy3D."
-                "Support for slabs oriented in other axes will be available in future releases."
-            )
-        return val
-
     @property
     def center_axis(self) -> float:
         """Gets the position of the center of the geometry in the out of plane dimension."""
@@ -1722,6 +1884,8 @@ class PolySlab(Planar):
             Whether point ``(x,y,z)`` is inside geometry.
         """
 
+        z, (x, y) = self.pop_axis((x, y, z), axis=self.axis)
+
         z0 = self.center_axis
         dist_z = np.abs(z - z0)
         inside_height = dist_z <= (self.length_axis / 2)
@@ -1756,16 +1920,32 @@ class PolySlab(Planar):
                 inside_polygon[inside_height] = inside_polygon_slab
             # slanted sidewall, offsetting vertices at each z
             else:
-                for z_i in range(z.shape[2]):
-                    if not inside_height[0, 0, z_i]:
+                # a helper function for moving axis
+                def _move_axis(arr):
+                    return np.moveaxis(arr, source=self.axis, destination=-1)
+
+                def _move_axis_reverse(arr):
+                    return np.moveaxis(arr, source=-1, destination=self.axis)
+
+                inside_polygon_axis = _move_axis(inside_polygon)
+                x_axis = _move_axis(x)
+                y_axis = _move_axis(y)
+
+                for z_i in range(z.shape[self.axis]):
+                    if not _move_axis(inside_height)[0, 0, z_i]:
                         continue
-                    vertices_z = self._shift_vertices(self.base_polygon, dist[0, 0, z_i])[0]
+                    vertices_z = self._shift_vertices(
+                        self.base_polygon, _move_axis(dist)[0, 0, z_i]
+                    )[0]
                     face_polygon = Polygon(vertices_z)
                     fun_contain = contains_pointwise(face_polygon)
                     contains_vectorized = np.vectorize(fun_contain, signature="(n)->()")
-                    points_stacked = np.stack((x[:, :, 0].flatten(), y[:, :, 0].flatten()), axis=1)
+                    points_stacked = np.stack(
+                        (x_axis[:, :, 0].flatten(), y_axis[:, :, 0].flatten()), axis=1
+                    )
                     inside_polygon_slab = contains_vectorized(points_stacked)
-                    inside_polygon[:, :, z_i] = inside_polygon_slab.reshape(x.shape[:2])
+                    inside_polygon_axis[:, :, z_i] = inside_polygon_slab.reshape(x_axis.shape[:2])
+                inside_polygon = _move_axis_reverse(inside_polygon_axis)
         else:
             vertices_z = self._shift_vertices(self._base_polygon, dist)[0]
             face_polygon = Polygon(vertices_z)
@@ -1831,7 +2011,9 @@ class PolySlab(Planar):
         # find out all z_i where the plane will intersect the vertex
         z0 = self.center_axis
         z_base = z0 - self.length_axis / 2
-        height_list = self._find_intersecting_height(position, axis)
+
+        axis_ordered = self._order_axis(axis)
+        height_list = self._find_intersecting_height(position, axis_ordered)
         polys = []
 
         # looping through z_i to assemble the polygons
@@ -1851,11 +2033,11 @@ class PolySlab(Planar):
             # for vertical sidewall, no need for complications
             if isclose(self.sidewall_angle, 0):
                 ints_y, ints_angle = self._find_intersecting_ys_angle_vertical(
-                    vertices, position, axis
+                    vertices, position, axis_ordered
                 )
             else:
                 ints_y, ints_angle = self._find_intersecting_ys_angle_slant(
-                    vertices, position, axis
+                    vertices, position, axis_ordered
                 )
 
             # make polygon with intersections and z axis information
@@ -1966,8 +2148,8 @@ class PolySlab(Planar):
         """
 
         vertices_axis = vertices.copy()
-        # if the first coordinate refers to bounds, need to flip the vertices x,y
-        if (axis == 2) or ((self.axis == 2) and (axis == 1)):
+        # flip vertices x,y for axis = y
+        if axis == 1:
             vertices_axis = np.roll(vertices_axis, shift=1, axis=1)
 
         # get the forward vertices
@@ -2043,8 +2225,8 @@ class PolySlab(Planar):
         """
 
         vertices_axis = vertices.copy()
-        # if the first coordinate refers to bounds, need to flip the vertices x,y
-        if (axis == 2) or ((self.axis == 2) and (axis == 1)):
+        # flip vertices x,y for axis = y
+        if axis == 1:
             vertices_axis = np.roll(vertices_axis, shift=1, axis=1)
 
         # get the forward vertices
